<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Presunúť vľavo</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Presunúť vpravo</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Odstrániť z rýchleho spustenia</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>CHyba pri pustení</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Súbor/URL „%1“ nateraz nemožno vložiť do rýchleho spustenia</translation>
    </message>
</context>
</TS>